# coding: utf-8

"""
    Battery Data API

    A standard API for accessing battery experiment datasets and metadata  # noqa: E501

    The version of the OpenAPI document: 2.1.10
    Contact: martin.robinson@cs.ox.ac.uk
    Generated by: https://openapi-generator.tech
"""

from galv.paths.equipment_.post import EquipmentCreate
from galv.paths.equipment_uuid_.delete import EquipmentDestroy
from galv.paths.equipment_.get import EquipmentList
from galv.paths.equipment_uuid_.patch import EquipmentPartialUpdate
from galv.paths.equipment_uuid_.get import EquipmentRetrieve


class EquipmentApi(
    EquipmentCreate,
    EquipmentDestroy,
    EquipmentList,
    EquipmentPartialUpdate,
    EquipmentRetrieve,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



from galv.paths.cell_families_uuid_.get import ApiForget
from galv.paths.cell_families_uuid_.delete import ApiFordelete
from galv.paths.cell_families_uuid_.patch import ApiForpatch


class CellFamiliesUuid(
    ApiForget,
    ApiFordelete,
    ApiForpatch,
):
    pass
